@@ -4,10 +4,8 @@ from . import templates
 
 from .logging import log
 
-logger = log.setup_custom_logger(name=__name__,
-    level="INFO",
-    file="./logs/app.log")
+logger = log.setup_custom_logger(name=__name__, level="INFO", file="./logs/app.log")
 
 logger.debug("created app.log log file")
 
-__version__ = "0.0.4"
\ No newline at end of file
+__version__ = "0.0.6"
