@@ -1,8 +1,8 @@
 """Headset and controller tracers."""
 from ..logging import log
 
-logger = log.setup_custom_logger(name=__name__,
-    level="INFO",
-    file="../logs/trackers.log")
+logger = log.setup_custom_logger(
+    name=__name__, level="INFO", file="../logs/trackers.log"
+)
 
-logger.debug("created trackers.log log file")
\ No newline at end of file
+logger.debug("created trackers.log log file")
