@@ -38,6 +38,7 @@ from ..calibration.manual_color_mask_calibration import load_mapdata_from_file
 from ..server import server
 from ..templates import ControllerState
 
+
 def check_serial_dict(ser_dict, key):
     if key in ser_dict:
         if ser_dict[key] in glob.glob("/dev/tty[A-Za-z]*"):
@@ -45,16 +46,30 @@ def check_serial_dict(ser_dict, key):
 
     return False
 
+
 class Poser(templates.PoserTemplate):
     """A pose estimator."""
 
-    def __init__(self, *args, camera=4, width=-1, height=-1, calibration_file=None, calibration_map_file=None, **kwargs):
+    def __init__(
+        self,
+        *args,
+        camera=4,
+        width=-1,
+        height=-1,
+        calibration_file=None,
+        calibration_map_file=None,
+        **kwargs,
+    ):
         """Create a pose estimator."""
         super().__init__(*args, **kwargs)
 
         self.temp_pose = ControllerState()
 
-        self.serialPaths = {"cont_r": "/dev/ttyUSB2","cont_l": "/dev/ttyUSB1", "hmd": "/dev/ttyUSB0"}
+        self.serialPaths = {
+            "cont_r": "/dev/ttyUSB2",
+            "cont_l": "/dev/ttyUSB1",
+            "hmd": "/dev/ttyUSB0",
+        }
 
         self.mode = 0
         self._serialResetYaw = False
@@ -67,26 +82,30 @@ class Poser(templates.PoserTemplate):
         if calibration_file is not None:
             try:
                 if calibration_map_file is not None:
-                    self.calibration = colordata_to_blob(CalibrationData.load_from_file(calibration_file), load_mapdata_from_file(calibration_map_file))
+                    self.calibration = colordata_to_blob(
+                        CalibrationData.load_from_file(calibration_file),
+                        load_mapdata_from_file(calibration_map_file),
+                    )
 
                 else:
-                    raise Exception('no map file provided')
+                    raise Exception("no map file provided")
 
             except Exception as e:
-                print (f'calibration file provided, but {repr(e)}, ignoring calibration file..')
+                print(
+                    f"calibration file provided, but {repr(e)}, ignoring calibration file.."
+                )
                 self.calibration = {
-                                "blue": {"h": (98, 10), "s": (200, 55), "v": (250, 32)},
-                                "green": {"h": (68, 15), "s": (135, 53), "v": (255, 50)},
-                                    }
+                    "blue": {"h": (98, 10), "s": (200, 55), "v": (250, 32)},
+                    "green": {"h": (68, 15), "s": (135, 53), "v": (255, 50)},
+                }
 
         else:
             self.calibration = {
-                            "blue": {"h": (98, 10), "s": (200, 55), "v": (250, 32)},
-                            "green": {"h": (68, 15), "s": (135, 53), "v": (255, 50)},
-                                }
-
-        print (f'current color masks {self.calibration}')
+                "blue": {"h": (98, 10), "s": (200, 55), "v": (250, 32)},
+                "green": {"h": (68, 15), "s": (135, 53), "v": (255, 50)},
+            }
 
+        print(f"current color masks {self.calibration}")
 
     @templates.PoserTemplate.register_member_thread(1 / 90)
     async def mode_switcher(self):
@@ -97,8 +116,12 @@ class Poser(templates.PoserTemplate):
                     self.pose_controller_l.trackpad_touch = 0
                     self.pose_controller_l.trackpad_x = 0
                     self.pose_controller_l.trackpad_y = 0
-                    self.pose_controller_r.trackpad_touch = self.temp_pose.trackpad_touch
-                    self.pose_controller_r.trackpad_click = self.temp_pose.trackpad_click
+                    self.pose_controller_r.trackpad_touch = (
+                        self.temp_pose.trackpad_touch
+                    )
+                    self.pose_controller_r.trackpad_click = (
+                        self.temp_pose.trackpad_click
+                    )
                     self.pose_controller_r.trackpad_x = self.temp_pose.trackpad_x
                     self.pose_controller_r.trackpad_y = self.temp_pose.trackpad_y
                     self.pose_controller_r.trigger_value = self.temp_pose.trigger_value
@@ -111,8 +134,12 @@ class Poser(templates.PoserTemplate):
                     self.pose_controller_r.trackpad_touch = 0
                     self.pose_controller_r.trackpad_x = 0
                     self.pose_controller_r.trackpad_y = 0
-                    self.pose_controller_l.trackpad_touch = self.temp_pose.trackpad_touch
-                    self.pose_controller_l.trackpad_click = self.temp_pose.trackpad_click
+                    self.pose_controller_l.trackpad_touch = (
+                        self.temp_pose.trackpad_touch
+                    )
+                    self.pose_controller_l.trackpad_click = (
+                        self.temp_pose.trackpad_click
+                    )
                     self.pose_controller_l.trackpad_x = self.temp_pose.trackpad_x
                     self.pose_controller_l.trackpad_y = self.temp_pose.trackpad_y
                     self.pose_controller_l.trigger_value = self.temp_pose.trigger_value
@@ -134,9 +161,7 @@ class Poser(templates.PoserTemplate):
         try:
             offsets = [0.6981317007977318, 0, 0]
             t1 = u.BlobTracker(
-                self.camera,
-                color_masks=self.calibration,
-                focal_length_px=554.2563
+                self.camera, color_masks=self.calibration, focal_length_px=554.2563
             )
 
         except Exception as e:
@@ -144,6 +169,8 @@ class Poser(templates.PoserTemplate):
             self.coro_keep_alive["get_location"].is_alive = False
             return
 
+        axisScale = np.array([0.8, 1/2, 0.8])
+
         with t1:
             while self.coro_keep_alive["get_location"].is_alive:
                 try:
@@ -151,20 +178,24 @@ class Poser(templates.PoserTemplate):
 
                     u.rotate(poses, offsets)
 
+                    poses *= axisScale
+
                     if self.usePos:
-                        self.pose_controller_l.x = round(-poses[1][0] * 0.9, 6)
-                        self.pose_controller_l.y = round(poses[1][1] * 0.85, 6)
-                        self.pose_controller_l.z = round(poses[1][2] * 1.8, 6)
+                        self.pose_controller_l.x = round(-poses[1][0], 6)
+                        self.pose_controller_l.y = round(poses[1][1], 6)
+                        self.pose_controller_l.z = round(poses[1][2], 6)
 
-                        self.pose_controller_r.x = round(-poses[2][0] * 0.9, 6)
-                        self.pose_controller_r.y = round(poses[2][1] * 0.85, 6)
-                        self.pose_controller_r.z = round(poses[2][2] * 1.8, 6)
+                        self.pose_controller_r.x = round(-poses[2][0], 6)
+                        self.pose_controller_r.y = round(poses[2][1], 6)
+                        self.pose_controller_r.z = round(poses[2][2], 6)
 
-                        self.pose.x = round(-poses[0][0] * 0.9 - 0.01, 6)
-                        self.pose.y = round(poses[0][1] * 0.85 - 0.07, 6)
-                        self.pose.z = round(poses[0][2] * 2 + 0.05, 6)
+                        self.pose.x = round(-poses[0][0] - 0.01, 6)
+                        self.pose.y = round(poses[0][1] - 0.07, 6)
+                        self.pose.z = round(poses[0][2], 6)
 
-                    await asyncio.sleep(self.coro_keep_alive["get_location"].sleep_delay)
+                    await asyncio.sleep(
+                        self.coro_keep_alive["get_location"].sleep_delay
+                    )
 
                 except Exception as e:
                     print("stopping get_location:", e)
@@ -175,12 +206,14 @@ class Poser(templates.PoserTemplate):
     @templates.PoserTemplate.register_member_thread(1 / 100)
     async def serial_listener2(self):
         """Get controller data from serial."""
-        irl_rot_off = Quaternion.from_z_rotation(np.pi/2) # imu on this controller is rotated 90 degrees irl for me
+        irl_rot_off = Quaternion.from_z_rotation(
+            np.pi / 2
+        )  # imu on this controller is rotated 90 degrees irl for me
 
         my_off = Quaternion()
 
-        if not check_serial_dict(self.serialPaths, 'cont_l'):
-            print ('failed to init serial_listener2: bad serial dict for key \'cont_l\'')
+        if not check_serial_dict(self.serialPaths, "cont_l"):
+            print("failed to init serial_listener2: bad serial dict for key 'cont_l'")
             self.coro_keep_alive["serial_listener2"].is_alive = False
             return
 
@@ -191,10 +224,23 @@ class Poser(templates.PoserTemplate):
 
                 while self.coro_keep_alive["serial_listener2"].is_alive:
                     try:
-                        gg = u.get_numbers_from_text(protocol.last_read, ',')
+                        gg = u.get_numbers_from_text(protocol.last_read, ",")
 
                         if len(gg) > 0:
-                            (w, x, y, z, trgr, grp, util, sys, menu, padClk, padY, padX,) = gg
+                            (
+                                w,
+                                x,
+                                y,
+                                z,
+                                trgr,
+                                grp,
+                                util,
+                                sys,
+                                menu,
+                                padClk,
+                                padY,
+                                padX,
+                            ) = gg
 
                             my_q = Quaternion([-y, z, -x, w])
 
@@ -210,8 +256,12 @@ class Poser(templates.PoserTemplate):
                             self.temp_pose.system = sys
                             self.temp_pose.trackpad_click = padClk
 
-                            self.temp_pose.trackpad_x = round((padX - 428) / 460, 3) * (-1)
-                            self.temp_pose.trackpad_y = round((padY - 530) / 540, 3) * (-1)
+                            self.temp_pose.trackpad_x = round((padX - 428) / 460, 3) * (
+                                -1
+                            )
+                            self.temp_pose.trackpad_y = round((padY - 530) / 540, 3) * (
+                                -1
+                            )
 
                             self._serialResetYaw = False
                             if self.temp_pose.trackpad_x > 0.6 and util:
@@ -230,7 +280,10 @@ class Poser(templates.PoserTemplate):
                                 my_off = Quaternion([0, z, 0, w]).inverse.normalised
                                 self._serialResetYaw = True
 
-                        if abs(self.temp_pose.trackpad_x) > 0.09 or abs(self.temp_pose.trackpad_y) > 0.09:
+                        if (
+                            abs(self.temp_pose.trackpad_x) > 0.09
+                            or abs(self.temp_pose.trackpad_y) > 0.09
+                        ):
                             self.temp_pose.trackpad_touch = 1
 
                         else:
@@ -242,7 +295,9 @@ class Poser(templates.PoserTemplate):
                         else:
                             self.temp_pose.trigger_click = 0
 
-                        await asyncio.sleep(self.coro_keep_alive["serial_listener2"].sleep_delay)
+                        await asyncio.sleep(
+                            self.coro_keep_alive["serial_listener2"].sleep_delay
+                        )
 
                     except Exception as e:
                         print(f"{self.serial_listener2.__name__}: {e}")
@@ -252,12 +307,14 @@ class Poser(templates.PoserTemplate):
     @templates.PoserTemplate.register_member_thread(1 / 100)
     async def serial_listener3(self):
         """Get orientation data from serial."""
-        irl_rot_off = Quaternion.from_x_rotation(np.pi/3) # imu on this controller is rotated 90 degrees irl for me
+        irl_rot_off = Quaternion.from_x_rotation(
+            np.pi / 2
+        )  # imu on this controller is rotated 90 degrees irl for me
 
         my_off = Quaternion()
 
-        if not check_serial_dict(self.serialPaths, 'cont_r'):
-            print ('failed to init serial_listener3: bad serial dict for key \'cont_r\'')
+        if not check_serial_dict(self.serialPaths, "cont_r"):
+            print("failed to init serial_listener3: bad serial dict for key 'cont_r'")
             self.coro_keep_alive["serial_listener3"].is_alive = False
             return
 
@@ -268,7 +325,7 @@ class Poser(templates.PoserTemplate):
 
                 while self.coro_keep_alive["serial_listener3"].is_alive:
                     try:
-                        gg = u.get_numbers_from_text(protocol.last_read, ',')
+                        gg = u.get_numbers_from_text(protocol.last_read, ",")
 
                         if len(gg) > 0:
                             w, x, y, z = gg
@@ -283,7 +340,9 @@ class Poser(templates.PoserTemplate):
                             self.pose_controller_r.r_y = round(my_q[1], 5)
                             self.pose_controller_r.r_z = round(my_q[2], 5)
 
-                        await asyncio.sleep(self.coro_keep_alive["serial_listener3"].sleep_delay)
+                        await asyncio.sleep(
+                            self.coro_keep_alive["serial_listener3"].sleep_delay
+                        )
 
                     except Exception as e:
                         print(f"{self.serial_listener.__name__}: {e}")
@@ -295,12 +354,11 @@ class Poser(templates.PoserTemplate):
         """Get orientation data from serial."""
         my_off = Quaternion()
 
-        if not check_serial_dict(self.serialPaths, 'hmd'):
-            print ('failed to init serial_listener: bad serial dict for key \'hmd\'')
+        if not check_serial_dict(self.serialPaths, "hmd"):
+            print("failed to init serial_listener: bad serial dict for key 'hmd'")
             self.coro_keep_alive["serial_listener"].is_alive = False
             return
 
-
         with serial.Serial(self.serialPaths["hmd"], 115200, timeout=1 / 5) as ser2:
             with serial.threaded.ReaderThread(ser2, u.SerialReaderFactory) as protocol:
                 protocol.write_line("nut")
@@ -308,7 +366,7 @@ class Poser(templates.PoserTemplate):
 
                 while self.coro_keep_alive["serial_listener"].is_alive:
                     try:
-                        gg = u.get_numbers_from_text(protocol.last_read, ',')
+                        gg = u.get_numbers_from_text(protocol.last_read, ",")
 
                         if len(gg) > 0:
                             w, x, y, z = gg
@@ -323,22 +381,29 @@ class Poser(templates.PoserTemplate):
                             self.pose.r_y = round(my_q[1], 5)
                             self.pose.r_z = round(my_q[2], 5)
 
-                        await asyncio.sleep(self.coro_keep_alive["serial_listener"].sleep_delay)
+                        await asyncio.sleep(
+                            self.coro_keep_alive["serial_listener"].sleep_delay
+                        )
 
                     except Exception as e:
                         print(f"{self.serial_listener.__name__}: {e}")
                         break
         self.coro_keep_alive["serial_listener"].is_alive = False
 
+
 def run_poser_only(addr="127.0.0.1", cam=4, colordata=None, mapdata=None):
     """Run the poser only. The server must be started in another program."""
-    t = Poser(addr=addr, camera=cam, calibration_file=colordata, calibration_map_file=mapdata)
+    t = Poser(
+        addr=addr, camera=cam, calibration_file=colordata, calibration_map_file=mapdata
+    )
     asyncio.run(t.main())
 
 
 def run_poser_and_server(addr="127.0.0.1", cam=4, colordata=None, mapdata=None):
     """Run the poser and server in one program."""
-    t = Poser(addr=addr, camera=cam, calibration_file=colordata, calibration_map_file=mapdata)
+    t = Poser(
+        addr=addr, camera=cam, calibration_file=colordata, calibration_map_file=mapdata
+    )
     server.run_til_dead(t)
 
 
@@ -353,7 +418,7 @@ def main():
 
     width, height = args["--resolution"].split("x")
 
-    print (args)
+    print(args)
 
     if args["--camera"].isdigit():
         cam = int(args["--camera"])
@@ -361,6 +426,16 @@ def main():
         cam = args["--camera"]
 
     if args["--standalone"]:
-        run_poser_and_server(args["--ip_address"], cam, args['--load_calibration'], args['--load_calibration_map'])
+        run_poser_and_server(
+            args["--ip_address"],
+            cam,
+            args["--load_calibration"],
+            args["--load_calibration_map"],
+        )
     else:
-        run_poser_only(args["--ip_address"], cam, args['--load_calibration'], args['--load_calibration_map'])
+        run_poser_only(
+            args["--ip_address"],
+            cam,
+            args["--load_calibration"],
+            args["--load_calibration_map"],
+        )
